import numpy as np
def testing_package():
    print("Checking how to convert python file into package")

def dot_prod_array(a,b):
    print('Array1:',a)
    print('Array2',b)
    print('Dot product of Array1 and Array2',np.dot(a,b))
